pub enum QuantizationConfig {
Scalar(ScalarQuantization),
Product(ProductQuantization),
Binary(BinaryQuantization),
}Variants
Implementations
Sourceimpl QuantizationConfig
impl QuantizationConfig
Sourcepub fn for_appendable_segment(opt: Option<&Self>) -> Option<Self>
pub fn for_appendable_segment(opt: Option<&Self>) -> Option<Self>
If appendable_quantization feature is enabled and config supports appendable segments,
returns the config for use in appendable segment; otherwise None.
Sourcepub fn mismatch_requires_rebuild(&self, other: &Self) -> bool
pub fn mismatch_requires_rebuild(&self, other: &Self) -> bool
Detect configuration mismatch against other that requires rebuilding
Returns true only if both conditions are met:
- this configuration does not match
other - to effectively change the configuration, a quantization rebuild is required
pub fn supports_appendable(&self) -> bool