pub enum VectorInternal {
Dense(Vec<f32>),
Sparse(SparseVector),
MultiDense(TypedMultiDenseVector<f32>),
}Variants
Implementations
Sourceimpl VectorInternal
impl VectorInternal
Sourcepub fn similarity_cost(&self) -> usize
pub fn similarity_cost(&self) -> usize
Returns the estimated cost of using this vector in terms of the number of how many similarity comparisons vector will make against one point.
Sourcepub fn preprocess(&mut self)
pub fn preprocess(&mut self)
Preprocess the vector
For a sparse vector, indices will be sorted.
pub fn from_vector_and_indices( vector: Vec<f32>, indices: Option<Vec<u32>>, ) -> Self