pub enum VectorNameConfig {
Dense(DenseVectorNameConfig),
Sparse(SparseVectorNameConfig),
}Expand description
Configuration for creating a new named vector.
Contains only the immutable properties that define a vector space. Storage type, index, and quantization are determined automatically based on the segment type and can be configured separately later.
Example JSON for a dense vector:
{ "dense": { "size": 768, "distance": "Cosine" } }Example JSON for a sparse vector:
{ "sparse": { "modifier": "Idf" } }Variants
Implementations
Sourceimpl VectorNameConfig
impl VectorNameConfig
pub fn dense(config: DenseVectorConfig) -> Self
pub fn sparse(config: SparseVectorConfig) -> Self