pub enum VectorPersisted {
Dense(Vec<f32>),
Sparse(SparseVector),
MultiDense(Vec<Vec<f32>>),
}Expand description
Single vector data, as it is persisted in WAL
Unlike [api::rest::Vector], this struct only stores raw vectors, inferenced or resolved.
Unlike VectorInternal, is not optimized for search
Variants
Implementations
Sourceimpl VectorPersisted
impl VectorPersisted
pub fn new_sparse(indices: Vec<u32>, values: Vec<f32>) -> Self
pub fn empty_sparse() -> Self