pub struct CountRequest {
pub filter: Option<Filter>,
pub exact: bool,
}Expand description
Count Request Counts the number of points which satisfy the given filter. If filter is not provided, the count of all points in the collection will be returned.
Fields
filter: Option<Filter>Look only for points which satisfies this conditions
exact: boolIf true, count exact number of points. If false, count approximate number of points faster. Approximate count might be unreliable during the indexing process. Default: true
Implementations
Sourceimpl CountRequestInternal
impl CountRequestInternal
pub const fn default_exact() -> bool