pub struct DeletePayloadOp {
pub keys: Vec<JsonPath>,
pub points: Option<Vec<ExtendedPointId>>,
pub filter: Option<Filter>,
}Expand description
This data structure is used inside shard operations queue and supposed to be written into WAL of individual shard.
Unlike DeletePayload it does not contain shard_key field
as individual shard does not need to know about shard key
Fields
keys: Vec<JsonPath>List of payload keys to remove from payload
points: Option<Vec<ExtendedPointId>>Deletes values from each point in this list
filter: Option<Filter>Deletes values from points that satisfy this filter condition