EdgeShard

Struct EdgeShard 

pub struct EdgeShard { /* private fields */ }

Implementations

Source

impl EdgeShard

Source

impl EdgeShard

pub fn facet( &self, request: FacetRequestInternal, ) -> OperationResult<FacetResponse>

Returns facet hits for the given facet request.

Counts the number of points for each unique value of the specified payload key, optionally filtering by the given conditions.

Source

impl EdgeShard

pub fn info(&self) -> ShardInfo

Source

impl EdgeShard

pub fn optimize(&self) -> OperationResult<bool>

Run shard optimizers in-process and blocking until no more optimization plans are produced.

This is synchronous and does not spawn background optimization workers.

Source

impl EdgeShard

pub fn query( &self, request: ShardQueryRequest, ) -> OperationResult<Vec<ScoredPoint>>

pub fn rescore_with_formula( &self, formula: ParsedFormula, prefetches_results: Vec<Vec<ScoredPoint>>, limit: usize, score_threshold: Option<f32>, hw_measurement_acc: HwMeasurementAcc, ) -> OperationResult<Vec<ScoredPoint>>

Source

impl EdgeShard

pub fn retrieve( &self, point_ids: &[ExtendedPointId], with_payload: Option<WithPayloadInterface>, with_vector: Option<WithVector>, ) -> OperationResult<Vec<RecordInternal>>

Source

impl EdgeShard

pub fn scroll( &self, request: ScrollRequestInternal, ) -> OperationResult<(Vec<RecordInternal>, Option<ExtendedPointId>)>

pub fn query_scroll( &self, request: &QueryScrollRequestInternal, ) -> OperationResult<Vec<ScoredPoint>>

Source

impl EdgeShard

pub fn search( &self, search: CoreSearchRequest, ) -> OperationResult<Vec<ScoredPoint>>

This method is DEPRECATED and should be replaced with query.

Source

impl EdgeShard

pub fn unpack_snapshot( snapshot_path: &Path, target_path: &Path, ) -> OperationResult<()>

pub fn snapshot_manifest(&self) -> OperationResult<SnapshotManifest>

pub fn recover_partial_snapshot( shard_path: &Path, current_manifest: &SnapshotManifest, snapshot_path: &Path, snapshot_manifest: &SnapshotManifest, ) -> OperationResult<Self>

Source

impl EdgeShard

Source

impl EdgeShard

pub fn new(path: &Path, config: EdgeConfig) -> OperationResult<Self>

Create a new edge shard at path with the given configuration.

Fails if the shard already exists (i.e. the segments directory contains any segment). Configuration is required and is persisted to edge_config.json.

pub fn load(path: &Path, config: Option<EdgeConfig>) -> OperationResult<Self>

Load an edge shard from existing files at path.

  • If config is Some: check compatibility with loaded segments, then overwrite edge_config.json with it.
  • If config is None: load config from edge_config.json, or infer from segments; check compatibility, then persist so future loads have it.

Fails if no segments exist and no config can be loaded or inferred.

pub fn config(&self) -> RwLockReadGuard<'_, EdgeConfig>

pub fn path(&self) -> &Path

pub fn set_hnsw_config(&self, hnsw_config: HnswConfig) -> OperationResult<()>

Update global HNSW config and persist. Does not change per-vector HNSW.

pub fn set_vector_hnsw_config( &self, vector_name: &str, hnsw_config: HnswConfig, ) -> OperationResult<()>

Update HNSW config for a named vector and persist. Fails if the vector does not exist. Immutable fields (e.g. size, distance) cannot be changed.

pub fn set_optimizers_config( &self, optimizers: EdgeOptimizersConfig, ) -> OperationResult<()>

Update optimizer config and persist.

pub fn flush(&self)

pub fn drop_and_clean_config(self) -> OperationResult<()>

This function removes edge-specific config and closes the shard. Removing config might be necessary to avoid incompatibilities on snapshot recovery.