pub struct FacetRequest {
pub key: JsonPath,
pub limit: usize,
pub filter: Option<Filter>,
pub exact: bool,
}Expand description
Facet Request Counts the number of points for each unique value of a payload key.
Fields
key: JsonPathPayload key to facet on
limit: usizeMaximum number of facet hits to return. Default: 10
filter: Option<Filter>Look only for points which satisfy these conditions
exact: boolIf true, count exact number of points for each value. If false, count approximate number of points faster. Default: false
Implementations
Sourceimpl FacetRequestInternal
impl FacetRequestInternal
pub const DEFAULT_LIMIT: usize = 10
pub const fn default_limit() -> usize
pub const fn default_exact() -> bool