pub struct FloatIndexParams {
pub type: FloatIndexType,
pub is_principal: Option<bool>,
pub on_disk: Option<bool>,
pub enable_hnsw: Option<bool>,
}Fields
type: FloatIndexTypeis_principal: Option<bool>If true - use this key to organize storage of the collection data. This option assumes that this key will be used in majority of filtered requests.
on_disk: Option<bool>If true, store the index on disk. Default: false.
enable_hnsw: Option<bool>Enable HNSW graph building for this payload field. If true, builds additional HNSW links (Need payload_m > 0). Default: true.