pub struct GeoBoundingBox {
pub top_left: GeoPoint,
pub bottom_right: GeoPoint,
}Expand description
Geo filter request
Matches coordinates inside the rectangle, described by coordinates of lop-left and bottom-right edges
Fields
top_left: GeoPointCoordinates of the top left point of the area rectangle
bottom_right: GeoPointCoordinates of the bottom right point of the area rectangle
Implementations
Sourceimpl GeoBoundingBox
impl GeoBoundingBox
pub fn check_point(&self, point: &GeoPoint) -> bool