pub struct HnswIndexConfig {
pub m: usize,
pub ef_construct: usize,
pub full_scan_threshold: usize,
pub max_indexing_threads: usize,
pub on_disk: Option<bool>,
pub payload_m: Option<usize>,
pub inline_storage: Option<bool>,
}Expand description
Config of HNSW index
Fields
m: usizeNumber of edges per node in the index graph. Larger the value - more accurate the search, more space required.
ef_construct: usizeNumber of neighbours to consider during the index building. Larger the value - more accurate the search, more time required to build index.
full_scan_threshold: usizeMinimal size threshold (in KiloBytes) below which full-scan is preferred over HNSW search.
This measures the total size of vectors being queried against.
When the maximum estimated amount of points that a condition satisfies is smaller than
full_scan_threshold_kb, the query planner will use full-scan search instead of HNSW index
traversal for better performance.
Note: 1Kb = 1 vector of size 256
max_indexing_threads: usizeNumber of parallel threads used for background index building. If 0 - automatically select from 8 to 16. Best to keep between 8 and 16 to prevent likelihood of slow building or broken/inefficient HNSW graphs. On small CPUs, less threads are used.
on_disk: Option<bool>Store HNSW index on disk. If set to false, index will be stored in RAM. Default: false
payload_m: Option<usize>Custom M param for hnsw graph built for payload index. If not set, default M will be used.
inline_storage: Option<bool>Store copies of original and quantized vectors within the HNSW index file. Default: false. Enabling this option will trade the search speed for disk usage by reducing amount of random seeks during the search. Requires quantized vectors to be enabled. Multi-vectors are not supported.
Implementations
Sourceimpl HnswConfig
impl HnswConfig
Sourcepub fn mismatch_requires_rebuild(&self, other: &Self) -> bool
pub fn mismatch_requires_rebuild(&self, other: &Self) -> bool
Detect configuration mismatch against other that requires rebuilding
Returns true only if both conditions are met:
- this configuration does not match
other - to effectively change the configuration, a HNSW rebuild is required
For example, a change in max_indexing_threads will not require rebuilding because it
doesn’t affect the final index, and thus this would return false.