pub struct IsEmptyCondition {
pub is_empty: PayloadField,
}Expand description
Select points with empty payload for a specified field
Fields
is_empty: PayloadFieldTrait Implementations
Sourceimpl Clone for IsEmptyCondition
impl Clone for IsEmptyCondition
Sourcefn clone(&self) -> IsEmptyCondition
fn clone(&self) -> IsEmptyCondition
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IsEmptyCondition
impl Debug for IsEmptyCondition
Sourceimpl<'de> Deserialize<'de> for IsEmptyCondition
impl<'de> Deserialize<'de> for IsEmptyCondition
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<JsonPath> for IsEmptyCondition
impl From<JsonPath> for IsEmptyCondition
Sourceimpl Hash for IsEmptyCondition
impl Hash for IsEmptyCondition
Sourceimpl JsonSchema for IsEmptyCondition
impl JsonSchema for IsEmptyCondition
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for IsEmptyCondition
impl PartialEq for IsEmptyCondition
Sourceimpl Serialize for IsEmptyCondition
impl Serialize for IsEmptyCondition
impl Eq for IsEmptyCondition
impl StructuralPartialEq for IsEmptyCondition