pub struct JsonPath {
pub first_key: String,
pub rest: Vec<JsonPathItem>,
}Fields
first_key: Stringrest: Vec<JsonPathItem>Implementations
Sourceimpl JsonPath
impl JsonPath
Sourcepub fn value_get<'a>(
&self,
json_map: &'a Map<String, Value>,
) -> SmallVec<[&'a Value; 1]> ⓘ
pub fn value_get<'a>( &self, json_map: &'a Map<String, Value>, ) -> SmallVec<[&'a Value; 1]> ⓘ
Get values at a given JSON path from a JSON map.
Sourcepub fn value_set<'a>(
path: Option<&Self>,
dest: &'a mut Map<String, Value>,
src: &'a Map<String, Value>,
)
pub fn value_set<'a>( path: Option<&Self>, dest: &'a mut Map<String, Value>, src: &'a Map<String, Value>, )
Set values at a given JSON path in a JSON map.
Sourcepub fn value_remove(
&self,
json_map: &mut Map<String, Value>,
) -> SmallVec<[Value; 1]> ⓘ
pub fn value_remove( &self, json_map: &mut Map<String, Value>, ) -> SmallVec<[Value; 1]> ⓘ
Remove values at a given JSON path from a JSON map. Returns values that were removed.
Sourcepub fn value_filter(
json_map: &Map<String, Value>,
filter: impl Fn(&Self, &Value) -> bool,
) -> Map<String, Value>
pub fn value_filter( json_map: &Map<String, Value>, filter: impl Fn(&Self, &Value) -> bool, ) -> Map<String, Value>
Filter values in a JSON map based on a predicate.
Sourcepub fn strip_wildcard_suffix(&self) -> Self
pub fn strip_wildcard_suffix(&self) -> Self
Remove the wildcard suffix from the path, if it exists.
E.g. a.b[] -> a.b.
Sourcepub fn strip_prefix(&self, prefix: &Self) -> Option<Self>
pub fn strip_prefix(&self, prefix: &Self) -> Option<Self>
If self starts with prefix, returns a new path with the prefix removed.
Sourcepub fn array_key(&self) -> Self
pub fn array_key(&self) -> Self
Returns a new path with an array key appended to the end.
E.g. a.b -> a.b[].
pub fn has_wildcard_suffix(&self) -> bool
Sourcepub fn check_include_pattern(&self, pattern: &Self) -> bool
pub fn check_include_pattern(&self, pattern: &Self) -> bool
Check if a path is included in a list of patterns.
Basically, it checks if either the pattern or path is a prefix of the other.
Sourcepub fn check_exclude_pattern(&self, pattern: &Self) -> bool
pub fn check_exclude_pattern(&self, pattern: &Self) -> bool
Check if a path should be excluded by a pattern.
Basically, it checks if pattern is a prefix of path, but not the other way around.
pub fn extend_or_new(base: Option<&Self>, other: &Self) -> Self
Sourcepub fn compatible(&self, other: &Self) -> bool
pub fn compatible(&self, other: &Self) -> bool
Check if a path is a compatible prefix of another path or vice versa.
Sourcepub fn is_affected_by_value_remove(&self, path_to_remove: &JsonPath) -> bool
pub fn is_affected_by_value_remove(&self, path_to_remove: &JsonPath) -> bool
Check if the path will be affected by a call to path_to_remove.value_remove(_).