pub struct MatchTextAny {
pub text_any: String,
}Expand description
Full-text match of at least one token of the string.
Fields
text_any: StringTrait Implementations
Sourceimpl Clone for MatchTextAny
impl Clone for MatchTextAny
Sourcefn clone(&self) -> MatchTextAny
fn clone(&self) -> MatchTextAny
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MatchTextAny
impl Debug for MatchTextAny
Sourceimpl<'de> Deserialize<'de> for MatchTextAny
impl<'de> Deserialize<'de> for MatchTextAny
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for MatchTextAny
impl Hash for MatchTextAny
Sourceimpl JsonSchema for MatchTextAny
impl JsonSchema for MatchTextAny
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MatchTextAny
impl PartialEq for MatchTextAny
Sourceimpl Serialize for MatchTextAny
impl Serialize for MatchTextAny
impl Eq for MatchTextAny
impl StructuralPartialEq for MatchTextAny