pub struct MatchValue {
pub value: ValueVariants,
}Expand description
Exact match of the given value
Fields
value: ValueVariantsTrait Implementations
Sourceimpl Clone for MatchValue
impl Clone for MatchValue
Sourcefn clone(&self) -> MatchValue
fn clone(&self) -> MatchValue
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MatchValue
impl Debug for MatchValue
Sourceimpl<'de> Deserialize<'de> for MatchValue
impl<'de> Deserialize<'de> for MatchValue
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for MatchValue
impl Hash for MatchValue
Sourceimpl JsonSchema for MatchValue
impl JsonSchema for MatchValue
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MatchValue
impl PartialEq for MatchValue
Sourceimpl Serialize for MatchValue
impl Serialize for MatchValue
impl Eq for MatchValue
impl StructuralPartialEq for MatchValue