pub struct Mmr {
pub vector: VectorInternal,
pub using: String,
pub lambda: OrderedFloat<f32>,
pub candidates_limit: usize,
}Expand description
Maximal Marginal Relevance configuration
Fields
vector: VectorInternalQuery vector, used to get the relevance of each point.
using: StringVector name to use for similarity computation, defaults to empty string (default vector)
lambda: OrderedFloat<f32>Lambda parameter controlling diversity vs relevance trade-off (0.0 = full diversity, 1.0 = full relevance)
candidates_limit: usizeMaximum number of candidates to preselect using nearest neighbors.