pub struct QuantizationSearchParams {
pub ignore: bool,
pub rescore: Option<bool>,
pub oversampling: Option<f64>,
}Expand description
Additional parameters of the search
Fields
ignore: boolIf true, quantized vectors are ignored. Default is false.
rescore: Option<bool>If true, use original vectors to re-score top-k results. Might require more time in case if original vectors are stored on disk. If not set, qdrant decides automatically apply rescoring or not.
oversampling: Option<f64>Oversampling factor for quantization. Default is 1.0.
Defines how many extra vectors should be preselected using quantized index, and then re-scored using original vectors.
For example, if oversampling is 2.4 and limit is 100, then 240 vectors will be preselected using quantized index,
and then top-100 will be returned after re-scoring.