pub struct QueryRequest {
pub prefetches: Vec<ShardPrefetch>,
pub query: Option<ScoringQuery>,
pub filter: Option<Filter>,
pub score_threshold: Option<OrderedFloat<f32>>,
pub limit: usize,
pub offset: usize,
pub params: Option<SearchParams>,
pub with_vector: WithVector,
pub with_payload: WithPayloadInterface,
}Expand description
Internal representation of a universal query request.
Direct translation of the user-facing request, but with all point ids substituted with their corresponding vectors.
For the case of formula queries, it collects conditions and variables too.
Fields
prefetches: Vec<ShardPrefetch>query: Option<ScoringQuery>filter: Option<Filter>score_threshold: Option<OrderedFloat<f32>>limit: usizeoffset: usizeparams: Option<SearchParams>Search params for when there is no prefetch
with_vector: WithVectorwith_payload: WithPayloadInterfaceImplementations
Sourceimpl ShardQueryRequest
impl ShardQueryRequest
pub fn prefetches_depth(&self) -> usize
pub fn filter_refs(&self) -> Vec<Option<&Filter>>