pub struct RetrieveRequest {
pub point_ids: Vec<ExtendedPointId>,
pub with_payload: Option<WithPayloadInterface>,
pub with_vector: Option<WithVector>,
}Expand description
Retrieve points by their ids. The response preserves the requested id order and skips ids that do not exist in the shard.
Fields
point_ids: Vec<ExtendedPointId>Ids of the points to retrieve.
with_payload: Option<WithPayloadInterface>Select which payload to return with the response. Default is true.
with_vector: Option<WithVector>Options for specifying which vectors to include into the response. Default is false.
Implementations
Sourceimpl RetrieveRequest
impl RetrieveRequest
pub fn new(point_ids: Vec<ExtendedPointId>) -> Self