pub struct SearchParams {
pub hnsw_ef: Option<usize>,
pub exact: bool,
pub quantization: Option<QuantizationSearchParams>,
pub indexed_only: bool,
pub acorn: Option<AcornSearchParams>,
}Expand description
Additional parameters of the search
Fields
hnsw_ef: Option<usize>Params relevant to HNSW index Size of the beam in a beam-search. Larger the value - more accurate the result, more time required for search.
exact: boolSearch without approximation. If set to true, search may run long but with exact results.
quantization: Option<QuantizationSearchParams>Quantization params
indexed_only: boolIf enabled, the engine will only perform search among indexed or small segments. Using this option prevents slow searches in case of delayed index, but does not guarantee that all uploaded vectors will be included in search results
acorn: Option<AcornSearchParams>ACORN search params