pub struct SearchRequest {
pub query: QueryEnum,
pub filter: Option<Filter>,
pub params: Option<SearchParams>,
pub limit: usize,
pub offset: usize,
pub with_payload: Option<WithPayloadInterface>,
pub with_vector: Option<WithVector>,
pub score_threshold: Option<f32>,
}Expand description
DEPRECATED: Search method should be removed and replaced with ShardQueryRequest
Fields
query: QueryEnumEvery kind of query that can be performed on segment level
filter: Option<Filter>Look only for points which satisfies this conditions
params: Option<SearchParams>Additional search params
limit: usizeMax number of result to return
offset: usizeOffset of the first result to return. May be used to paginate results. Note: large offset values may cause performance issues.
with_payload: Option<WithPayloadInterface>Select which payload to return with the response. Default is false.
with_vector: Option<WithVector>Options for specifying which vectors to include into response. Default is false.
score_threshold: Option<f32>Implementations
Sourceimpl CoreSearchRequest
impl CoreSearchRequest
pub fn search_rate_cost(&self) -> usize