pub struct SearchRequestBuilder { /* private fields */ }Expand description
Fluent builder for SearchRequest.
query and limit are required and passed through Self::new; every
other field is optional and falls back to the SearchRequest::new defaults.
Implementations
Sourceimpl SearchRequestBuilder
impl SearchRequestBuilder
pub fn new(query: QueryEnum, limit: usize) -> Self
pub fn filter(self, filter: Filter) -> Self
pub fn params(self, params: SearchParams) -> Self
pub fn offset(self, offset: usize) -> Self
pub fn with_payload(self, with_payload: WithPayloadInterface) -> Self
pub fn with_vector(self, with_vector: WithVector) -> Self
pub fn score_threshold(self, score_threshold: f32) -> Self
pub fn build(self) -> SearchRequest