pub struct SparseVector {
pub indices: Vec<u32>,
pub values: Vec<f32>,
}Expand description
Sparse vector structure
Fields
indices: Vec<u32>Indices must be unique
values: Vec<f32>Values and indices must be the same length
Implementations
Sourceimpl SparseVector
impl SparseVector
pub fn new( indices: Vec<u32>, values: Vec<f32>, ) -> Result<Self, ValidationErrors>
Sourcepub fn sort_by_indices(&mut self)
pub fn sort_by_indices(&mut self)
Sort this vector by indices.
Sorting is required for scoring and overlap checks.
Sourcepub fn score(&self, other: &SparseVector) -> Option<f32>
pub fn score(&self, other: &SparseVector) -> Option<f32>
Score this vector against another vector using dot product. Warning: Expects both vectors to be sorted by indices.
Return None if the vectors do not overlap.
Sourcepub fn combine_aggregate(
&self,
other: &SparseVector,
op: impl Fn(f32, f32) -> f32,
) -> Self
pub fn combine_aggregate( &self, other: &SparseVector, op: impl Fn(f32, f32) -> f32, ) -> Self
Construct a new vector that is the result of performing all indices-wise operations. Automatically sort input vectors if necessary.