ScoringQuery

Enum ScoringQuery 

pub enum ScoringQuery {
    Vector(QueryEnum),
    Fusion(FusionInternal),
    OrderBy(OrderBy),
    Formula(ParsedFormula),
    Sample(SampleInternal),
    Mmr(MmrInternal),
}
Same as Query, but with the resolved vector references.

Variants



Vector(QueryEnum)

Score points against some vector(s)



Fusion(FusionInternal)

Reciprocal rank fusion



OrderBy(OrderBy)

Order by a payload field



Formula(ParsedFormula)

Score boosting via an arbitrary formula



Sample(SampleInternal)

Sample points



Mmr(MmrInternal)

Maximal Marginal Relevance

This one behaves a little differently than the other scorings, since it is two parts. It will create one nearest neighbor search in segment space and then try to resolve MMR algorithm higher up.

E.g. If it is the root query of a request:

  1. Performs search all the way down to segments.
  2. MMR gets calculated once results reach collection level.

Implementations

Source

impl ScoringQuery

pub fn needs_intermediate_results(&self) -> bool

Whether the query needs the prefetches results from all shards to compute the final score

If false, there is a single list of scored points which contain the final score.

pub fn get_vector_name(&self) -> Option<&str>

Get the vector name if it is scored against a vector