pub struct EdgeShard { /* private fields */ }Implementations
Sourceimpl EdgeShard
impl EdgeShard
pub fn count(&self, request: CountRequestInternal) -> OperationResult<usize>
Sourceimpl EdgeShard
impl EdgeShard
Sourcepub fn facet(
&self,
request: FacetRequestInternal,
) -> OperationResult<FacetResponse>
pub fn facet( &self, request: FacetRequestInternal, ) -> OperationResult<FacetResponse>
Returns facet hits for the given facet request.
Counts the number of points for each unique value of the specified payload key, optionally filtering by the given conditions.
Sourceimpl EdgeShard
impl EdgeShard
Sourcepub fn optimize(&self) -> OperationResult<bool>
pub fn optimize(&self) -> OperationResult<bool>
Run shard optimizers in-process and blocking until no more optimization plans are produced.
This is synchronous and does not spawn background optimization workers.
Sourceimpl EdgeShard
impl EdgeShard
pub fn query( &self, request: ShardQueryRequest, ) -> OperationResult<Vec<ScoredPoint>>
pub fn rescore_with_formula( &self, formula: ParsedFormula, prefetches_results: Vec<Vec<ScoredPoint>>, limit: usize, score_threshold: Option<f32>, hw_measurement_acc: HwMeasurementAcc, ) -> OperationResult<Vec<ScoredPoint>>
Sourceimpl EdgeShard
impl EdgeShard
pub fn retrieve( &self, point_ids: &[ExtendedPointId], with_payload: Option<WithPayloadInterface>, with_vector: Option<WithVector>, ) -> OperationResult<Vec<RecordInternal>>
Sourceimpl EdgeShard
impl EdgeShard
pub fn scroll( &self, request: ScrollRequestInternal, ) -> OperationResult<(Vec<RecordInternal>, Option<ExtendedPointId>)>
pub fn query_scroll( &self, request: &QueryScrollRequestInternal, ) -> OperationResult<Vec<ScoredPoint>>
Sourceimpl EdgeShard
impl EdgeShard
Sourcepub fn search(
&self,
search: CoreSearchRequest,
) -> OperationResult<Vec<ScoredPoint>>
pub fn search( &self, search: CoreSearchRequest, ) -> OperationResult<Vec<ScoredPoint>>
This method is DEPRECATED and should be replaced with query.
Sourceimpl EdgeShard
impl EdgeShard
pub fn unpack_snapshot( snapshot_path: &Path, target_path: &Path, ) -> OperationResult<()>
pub fn snapshot_manifest(&self) -> OperationResult<SnapshotManifest>
pub fn recover_partial_snapshot( shard_path: &Path, current_manifest: &SnapshotManifest, snapshot_path: &Path, snapshot_manifest: &SnapshotManifest, ) -> OperationResult<Self>
Sourceimpl EdgeShard
impl EdgeShard
pub fn update( &self, operation: CollectionUpdateOperations, ) -> OperationResult<()>
Sourceimpl EdgeShard
impl EdgeShard
Sourcepub fn new(path: &Path, config: EdgeConfig) -> OperationResult<Self>
pub fn new(path: &Path, config: EdgeConfig) -> OperationResult<Self>
Create a new edge shard at path with the given configuration.
Fails if the shard already exists (i.e. the segments directory contains any segment).
Configuration is required and is persisted to edge_config.json.
Sourcepub fn load(path: &Path, config: Option<EdgeConfig>) -> OperationResult<Self>
pub fn load(path: &Path, config: Option<EdgeConfig>) -> OperationResult<Self>
Load an edge shard from existing files at path.
- If
configisSome: check compatibility with loaded segments, then overwriteedge_config.jsonwith it. - If
configisNone: load config fromedge_config.json, or infer from segments; check compatibility, then persist so future loads have it.
Fails if no segments exist and no config can be loaded or inferred.
pub fn config(&self) -> RwLockReadGuard<'_, EdgeConfig>
pub fn path(&self) -> &Path
Sourcepub fn set_hnsw_config(&self, hnsw_config: HnswConfig) -> OperationResult<()>
pub fn set_hnsw_config(&self, hnsw_config: HnswConfig) -> OperationResult<()>
Update global HNSW config and persist. Does not change per-vector HNSW.
Sourcepub fn set_vector_hnsw_config(
&self,
vector_name: &str,
hnsw_config: HnswConfig,
) -> OperationResult<()>
pub fn set_vector_hnsw_config( &self, vector_name: &str, hnsw_config: HnswConfig, ) -> OperationResult<()>
Update HNSW config for a named vector and persist. Fails if the vector does not exist. Immutable fields (e.g. size, distance) cannot be changed.
Sourcepub fn set_optimizers_config(
&self,
optimizers: EdgeOptimizersConfig,
) -> OperationResult<()>
pub fn set_optimizers_config( &self, optimizers: EdgeOptimizersConfig, ) -> OperationResult<()>
Update optimizer config and persist.
pub fn flush(&self)
Sourcepub fn drop_and_clean_config(self) -> OperationResult<()>
pub fn drop_and_clean_config(self) -> OperationResult<()>
This function removes edge-specific config and closes the shard. Removing config might be necessary to avoid incompatibilities on snapshot recovery.